==> aws_sqs_api-0.0.4.tar.gz: README.md <==
# AWS API client for Amazon Simple Queue Service

**Warning: This is a generated library, some operations may not work.**

*About the service:*
Welcome to the <i>Amazon Simple Queue Service API Reference</i>.

Amazon Simple Queue Service (Amazon SQS) is a reliable, highly-scalable
hosted queue for storing messages as they travel between applications or
microservices. Amazon SQS moves data between distributed application
components and helps you decouple these components.

You can use <a href="http://aws.amazon.com/tools/#sdk">AWS SDKs</a> to
access Amazon SQS using your favorite programming language. The SDKs perform
tasks such as the following automatically:

<ul>
<li>
Cryptographically sign your service requests
</li>
<li>
Retry requests
</li>
<li>
Handle error responses
</li>
</ul>
<b>Additional Information</b>

<ul>
<li>
<a href="http://aws.amazon.com/sqs/">Amazon SQS Product Page</a>
</li>
<li>
<i>Amazon Simple Queue Service Developer Guide</i>

<ul>
<li>
<a
href="https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-making-api-requests.html">Making
API Requests</a>
</li>
<li>
<a
href="https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-message-attributes.html">Amazon
SQS Message Attributes</a>
</li>
<li>
<a
href="https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-dead-letter-queues.html">Amazon
SQS Dead-Letter Queues</a>
</li>
</ul> </li>
<li>
<a
href="http://docs.aws.amazon.com/cli/latest/reference/sqs/index.html">Amazon
SQS in the <i>AWS CLI Command Reference</i> </a>
</li>
<li>
<i>Amazon Web Services General Reference</i>

<ul>
<li>
<a
href="https://docs.aws.amazon.com/general/latest/gr/rande.html#sqs_region">Regions
and Endpoints</a>
</li>
</ul> </li>
</ul>

## Links

- [Other AWS libraries](https://github.com/agilord/aws_client/tree/master/generated).
- [Issue tracker](https://github.com/agilord/aws_client/issues).
- [AWS API definitions](https://github.com/aws/aws-sdk-js/tree/master/apis).

## Contributors

- [Jonathan Böcker](https://github.com/Schwusch)
- [Istvan Soós](https://github.com/isoos)

==> aws_sqs_api-1.2.0.tar.gz: README.md <==
# AWS API client for Amazon Simple Queue Service

**Warning: This is a generated library, some operations may not work.**

*About the service:*
Welcome to the <i>Amazon Simple Queue Service API Reference</i>.

Amazon Simple Queue Service (Amazon SQS) is a reliable, highly-scalable
hosted queue for storing messages as they travel between applications or
microservices. Amazon SQS moves data between distributed application
components and helps you decouple these components.

For information on the permissions you need to use this API, see <a
href="https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-authentication-and-access-control.html">Identity
and access management</a> in the <i>Amazon Simple Queue Service Developer
Guide.</i>

You can use <a href="https://aws.amazon.com/tools/#sdk">AWS SDKs</a> to
access Amazon SQS using your favorite programming language. The SDKs perform
tasks such as the following automatically:

<ul>
<li>
Cryptographically sign your service requests
</li>
<li>
Retry requests
</li>
<li>
Handle error responses
</li>
</ul>
<b>Additional Information</b>

<ul>
<li>
<a href="https://aws.amazon.com/sqs/">Amazon SQS Product Page</a>
</li>
<li>
<i>Amazon Simple Queue Service Developer Guide</i>

<ul>
<li>
<a
href="https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-making-api-requests.html">Making
API Requests</a>
</li>
<li>
<a
href="https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-message-metadata.html#sqs-message-attributes">Amazon
SQS Message Attributes</a>
</li>
<li>
<a
href="https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-dead-letter-queues.html">Amazon
SQS Dead-Letter Queues</a>
</li>
</ul> </li>
<li>
<a
href="https://docs.aws.amazon.com/cli/latest/reference/sqs/index.html">Amazon
SQS in the <i>AWS CLI Command Reference</i> </a>
</li>
<li>
<i>Amazon Web Services General Reference</i>

<ul>
<li>
<a
href="https://docs.aws.amazon.com/general/latest/gr/rande.html#sqs_region">Regions
and Endpoints</a>
</li>
</ul> </li>
</ul>

## Links

- [Other AWS libraries](https://github.com/agilord/aws_client/tree/master/generated).
- [Issue tracker](https://github.com/agilord/aws_client/issues).
- [AWS API definitions](https://github.com/aws/aws-sdk-js/tree/master/apis).

## Contributors

- [Jonathan Böcker](https://github.com/Schwusch)
- [Istvan Soós](https://github.com/isoos)
